@@ -40,7 +40,8 @@ from typing import Any, Literal, Mapping, Optional, Callable, Union, Iterable, I
 from inspect import Parameter
 import os
 from functools import partial
-
+import time
+from numbers import Number
 import dill  # pip install dill
 
 from i2 import Sig, double_up_as_factory
@@ -55,16 +56,16 @@ StoreName = KT
 Mall = Mapping[StoreName, StoreType]
 
 
-def auto_key(*args, **kwargs) -> KT:
+def auto_key_from_arguments(*args, **kwargs) -> KT:
     """Make a str key from arguments.
 
-    >>> auto_key(1,2,c=3,d=4)
+    >>> auto_key_from_arguments(1,2,c=3,d=4)
     '1,2,c=3,d=4'
-    >>> auto_key(1,2)
+    >>> auto_key_from_arguments(1,2)
     '1,2'
-    >>> auto_key(c=3,d=4)
+    >>> auto_key_from_arguments(c=3,d=4)
     'c=3,d=4'
-    >>> auto_key()
+    >>> auto_key_from_arguments()
     ''
     """
     args_str = ','.join(map(str, args))
@@ -72,6 +73,47 @@ def auto_key(*args, **kwargs) -> KT:
     return ','.join(filter(None, [args_str, kwargs_str]))
 
 
+auto_key = auto_key_from_arguments  # TODO: Deprecate this backcompatibility alias?
+
+
+def auto_key_from_time(
+    *args, __format: Union[Number, str, Callable] = 1e6, **kwargs
+) -> KT:
+    """Make a str key with current timestamp (ignoring arguments)
+
+    :param __format: When a number, will be used as a multiplier of current utc time
+
+    >>> auto_key_from_time()  # doctest: +SKIP
+    '1_669_724_787_630_906'
+
+    But `auto_key_from_time` is really meant to be used with ``functools.partial`` to
+    parametrize its ``__format``, such as:
+
+    >>> from functools import partial
+    >>>
+    >>> time_in_ms = partial(auto_key_from_time, __format=1e3)
+    >>> normal_format = partial(auto_key_from_time, __format='%Y-%m-%d %H:%M:%S')
+    >>> modulo_1000 = partial(auto_key_from_time, __format=lambda x: int(x % 1000))
+    >>>
+    >>> time_in_ms()  # doctest: +SKIP
+    '1_669_724_787_641'
+    >>> normal_format()  # doctest: +SKIP
+    '2022-11-29 12:26:27'
+    >>> modulo_1000()  # doctest: +SKIP
+    '788'
+    """
+    utc_seconds = time.time()
+    if isinstance(__format, Number):
+        return f'{int(utc_seconds * __format):_}'
+    elif isinstance(__format, str):
+        return time.strftime(__format, time.gmtime(utc_seconds))
+    else:
+        assert callable(
+            __format
+        ), f'__format should be callable, str or number. Was: {__format}'
+        return str(__format(utc_seconds))
+
+
 @wrap_kvs(data_of_obj=dill.dumps, obj_of_data=dill.loads)
 class DillFiles(Files):
     """Serializes and deserializes with dill"""
@@ -689,7 +731,8 @@ _Crudifier = sig_to_dataclass(
     Sig(prepare_for_crude_dispatch).params[1:], cls_name='_Crudifier', module=__name__,
 )
 
-
+# TODO: Should Crudifier be simply served by `i2.FuncFactory(prepare_for_crude_dispatch)` (without first arg)?
+#   Might want this issue solved first: https://github.com/i2mint/i2/issues/39
 class Crudifier(_Crudifier):
     """Convenience class to make crudify (i.e. map/source inputs of) functions.
 
@@ -832,7 +875,7 @@ def _remove_non_valued_items(d: dict):
 
 
 def _keys_to_search(func):
-    """Function defining what forms of keys will be searched in the arg_input_stores
+    """Function defining what forms of keys will be searched in the param_to_mall_map
     when using crudify_based_on_names on a function.
     Note that since chain_get will be used on this, it's the first key found that will be used,
     making, for example, a ``(func, arg_name)`` specification have precedence over an `arg_name` specification"""
@@ -850,14 +893,14 @@ def _keys_to_search(func):
 
 
 def crudify_based_on_names(
-    func, *, arg_input_stores=(), func_output_stores=(), crudifier=Crudifier
+    func, *, param_to_mall_map=(), output_store=(), crudifier=Crudifier
 ):
     """
     Crudify a function based on general
 
     :param func:
-    :param arg_input_stores:
-    :param func_output_stores:
+    :param param_to_mall_map:
+    :param output_store:
     :param crudifier:
     :return:
 
@@ -868,7 +911,7 @@ def crudify_based_on_names(
     ...     return a * x
     >>> general_crudifier = partial(
     ...     crudify_based_on_names,
-    ...     arg_input_stores={'x': 'x_store'},
+    ...     param_to_mall_map={'x': 'x_store'},
     ...     crudifier=partial(prepare_for_crude_dispatch, mall={'x_store': {'stored_two': 2, 'stored_four': 4}})
     ... )
     >>>
@@ -880,19 +923,19 @@ def crudify_based_on_names(
     16
 
     """
-    arg_input_stores = dict(arg_input_stores)
-    func_output_stores = dict(func_output_stores)
+    param_to_mall_map = dict(param_to_mall_map)
+    output_store = dict(output_store)
     func_name = name_of_obj(func)
     param_to_mall_map = (
         _remove_non_valued_items(
             {
-                arg_name: chain_get(arg_input_stores, keys)
+                arg_name: chain_get(param_to_mall_map, keys)
                 for arg_name, keys in _keys_to_search(func)
             }
         )
         or None
     )
-    output_store = chain_get(func_output_stores, (func, func_name), default=None)
+    output_store = chain_get(output_store, (func, func_name), default=None)
     if param_to_mall_map or output_store:
         return crudifier(
             func, param_to_mall_map=param_to_mall_map, output_store=output_store
